Learn R Programming

gclm (version 0.0.1)

gclm.lowertri: Recover lower triangular GCLM

Description

Recover the only lower triangular stable matrix B such that Sigma (\(\Sigma\)) is the solution of the associated continuous Lyapunov equation: $$B\Sigma + \Sigma B' + C = 0$$

Usage

gclm.lowertri(Sigma, P = solve(Sigma), C = diag(nrow = nrow(Sigma)))

Arguments

Sigma

covariance matrix

P

the inverse of the covariance matrix

C

symmetric positive definite matrix

Value

A stable lower triangular matrix